package javax.rmi.CORBA;

import java.io.FileInputStream;
import java.io.File;
import java.util.Properties;
import java.security.AccessController;
import java.security.PrivilegedAction;

class GetORBPropertiesFileAction implements PrivilegedAction
{
    private boolean debug;
    
    public GetORBPropertiesFileAction() {
        this.debug = false;
    }
    
    private String getSystemProperty(final String s) {
        return (String)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return System.getProperty(s);
            }
        });
    }
    
    private void getPropertiesFromFile(Properties properties, String s) {
        try {
            File file = new File(s);
            if (!file.exists()) {
                return;
            }
            FileInputStream inStream = new FileInputStream(file);
            try {
                properties.load(inStream);
            }
            finally {
                inStream.close();
            }
        }
        catch (Exception obj) {
            if (this.debug) {
                System.out.println("ORB properties file " + s + " not found: " + obj);
            }
        }
    }
    
    @Override
    public Object run() {
        Properties defaults = new Properties();
        this.getPropertiesFromFile(defaults, this.getSystemProperty("java.home") + File.separator + "lib" + File.separator + "orb.properties");
        Properties properties = new Properties(defaults);
        this.getPropertiesFromFile(properties, this.getSystemProperty("user.home") + File.separator + "orb.properties");
        return properties;
    }
}
